config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/modules.conf.new
config etc/modprobe.conf.new
rm -f etc/modules.conf.new
rm -f etc/modprobe.conf.new
( cd sbin ; rm -rf ksyms )
( cd sbin ; ln -sf insmod.old ksyms )
( cd sbin ; rm -rf lsmod.old )
( cd sbin ; ln -sf insmod.old lsmod.old )
( cd sbin ; rm -rf modprobe.old )
( cd sbin ; ln -sf insmod.old modprobe.old )
( cd sbin ; rm -rf rmmod.old )
( cd sbin ; ln -sf insmod.old rmmod.old )
( cd sbin ; rm -rf kallsyms )
( cd sbin ; ln -sf insmod.old kallsyms )
( cd bin ; rm -rf lsmod )
( cd bin ; ln -sf /sbin/lsmod lsmod )
( cd bin ; rm -rf lsmod.old )
( cd bin ; ln -sf /sbin/lsmod.old lsmod.old )
